@@ -10,9 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from toscaparser.common.exception import URLException
 from toscaparser.tests.base import TestCase
-from toscaparser.utils.gettextutils import _
 import toscaparser.utils.urlutils
 import toscaparser.utils.yamlparser
 
@@ -47,14 +45,3 @@ class UrlUtilsTest(TestCase):
             self.url_utils.join_url("http://github.com/proj1/scripts",
                                     "scripts/b.js"),
             "http://github.com/proj1/scripts/b.js")
-
-    def test_load_url_errors(self):
-        url = "http://www.badurl."
-        err_msg = (_('Failed to reach server "%(url)s". Reason is: '
-                   '[Errno -2] Name or service not known.')
-                   % {'url': url})
-        err = self.assertRaises(URLException,
-                                YAML_LOADER,
-                                url,
-                                False)
-        self.assertEqual(err_msg, err.__str__())
